darkhistory.history.histools.IonRSInterp — DarkHistory documentation

# darkhistory.history.histools.IonRSInterp

class `darkhistory.history.histools.` `IonRSInterp`(ionrsarrays, rs_nodes=None, log_interp=False)

  Interpolation function over list of IonRSArray objects.

  Parameters: | ionrsarrays : list of IonRSArray IonRSArray objects to interpolate over. rs_nodes : ndarray List of redshifts to transition between redshift regimes. log_interp : bool, optional If true, performs an interpolation over log of the grid values.

  Methods

  get_val |

  `__init__`(ionrsarrays, rs_nodes=None, log_interp=False)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(ionrsarrays[, rs_nodes, log_interp]) | Initialize self.
  `get_val`(xH, xHe, rs) |

#### Previous topic

darkhistory.history.histools.IonRSArray

#### Next topic

darkhistory.history.reionization

### This Page

Show Source